@@ -263,7 +263,8 @@ LOCATION_MEMORY = 2
 DT_BLOCK = 0
 DZ_BLOCK_DEFLATE = 1
 DZ_BLOCK_TRANSPOSED = 2
-BLOSC_BLOCK = 3
+DZ_BLOCK_LZ = 3
+
 FMT_CHANNEL = "<4sI2Q{}Q4B4I2BH6d"
 FMT_CHANNEL_PARAMS = "<4B4I2BH6d"
 
