@@ -18,18 +18,20 @@ class ChannelDisplay(Ui_ChannelDiplay, QtWidgets.QWidget):
     individual_axis_changed = QtCore.pyqtSignal(object, int)
 
     __slots__ = (
-        'color',
-        '_value_prefix',
-        '_value',
-        '_name',
-        'fmt',
-        'uuid',
-        'ranges',
-        'unit',
-        '_transparent',
+        "color",
+        "_value_prefix",
+        "_value",
+        "_name",
+        "fmt",
+        "uuid",
+        "ranges",
+        "unit",
+        "_transparent",
     )
 
-    def __init__(self, uuid, unit="", kind='f', precision=3, *args, **kwargs):
+    def __init__(
+        self, uuid, unit="", kind="f", precision=3, tooltip="", *args, **kwargs
+    ):
         super().__init__(*args, **kwargs)
         self.setupUi(self)
 
@@ -45,6 +47,7 @@ class ChannelDisplay(Ui_ChannelDiplay, QtWidgets.QWidget):
         self.precision = precision
 
         self._transparent = True
+        self._tooltip = tooltip
 
         self.color_btn.clicked.connect(self.select_color)
         self.display.stateChanged.connect(self.display_changed)
@@ -53,17 +56,17 @@ class ChannelDisplay(Ui_ChannelDiplay, QtWidgets.QWidget):
 
         self.fm = QtGui.QFontMetrics(self.name.font())
 
-        self.setToolTip(self._name)
+        self.setToolTip(self._tooltip or self._name)
 
-        if kind in 'SUVui':
-            self.fmt = '{}'
+        if kind in "SUVui":
+            self.fmt = "{}"
         else:
-            self.fmt = f'{{:.{self.precision}f}}'
+            self.fmt = f"{{:.{self.precision}f}}"
 
     def set_precision(self, precision):
-        if self.kind == 'f':
+        if self.kind == "f":
             self.precision = precision
-            self.fmt = f'{{:.{self.precision}f}}'
+            self.fmt = f"{{:.{self.precision}f}}"
 
     def display_changed(self, state):
         state = self.display.checkState()
@@ -91,7 +94,7 @@ class ChannelDisplay(Ui_ChannelDiplay, QtWidgets.QWidget):
             self.color_changed.emit(self.uuid, color.name())
 
     def set_fmt(self, fmt):
-        if self.kind in 'fSUV':
+        if self.kind in "fSUV":
             pass
         else:
             if fmt == "hex":
@@ -108,7 +111,7 @@ class ChannelDisplay(Ui_ChannelDiplay, QtWidgets.QWidget):
         self.color_btn.setStyleSheet(f"background-color: {color};")
 
     def set_name(self, text=""):
-        self.setToolTip(text)
+        self.setToolTip(self._tooltip or text)
         self._name = text
 
     def set_prefix(self, text=""):
@@ -117,12 +120,21 @@ class ChannelDisplay(Ui_ChannelDiplay, QtWidgets.QWidget):
     def update(self):
         width = self.name.size().width()
         if self.unit:
-            self.name.setText(self.fm.elidedText(f'{self._name} ({self.unit})', QtCore.Qt.ElideMiddle, width))
+            self.name.setText(
+                self.fm.elidedText(
+                    f"{self._name} ({self.unit})", QtCore.Qt.ElideMiddle, width
+                )
+            )
         else:
-            self.name.setText(self.fm.elidedText(self._name, QtCore.Qt.ElideMiddle, width))
+            self.name.setText(
+                self.fm.elidedText(self._name, QtCore.Qt.ElideMiddle, width)
+            )
         self.set_value(self._value)
 
     def set_value(self, value):
+        if self._value == value:
+            return
+
         self._value = value
         if self.ranges and value not in ("", "n.a."):
             for (start, stop), color in self.ranges.items():
@@ -133,7 +145,7 @@ class ChannelDisplay(Ui_ChannelDiplay, QtWidgets.QWidget):
                 self.setStyleSheet("background-color: transparent;")
         elif not self._transparent:
             self.setStyleSheet("background-color: transparent;")
-        template = '{{}}{}'
+        template = "{{}}{}"
         if value not in ("", "n.a."):
             template = template.format(self.fmt)
         else:
@@ -141,7 +153,7 @@ class ChannelDisplay(Ui_ChannelDiplay, QtWidgets.QWidget):
         try:
             self.value.setText(template.format(self._value_prefix, value))
         except (ValueError, TypeError):
-            template = '{}{}'
+            template = "{}{}"
             self.value.setText(template.format(self._value_prefix, value))
 
     def keyPressEvent(self, event):
@@ -150,25 +162,33 @@ class ChannelDisplay(Ui_ChannelDiplay, QtWidgets.QWidget):
         if modifier == QtCore.Qt.ControlModifier and key == QtCore.Qt.Key_C:
             QtWidgets.QApplication.instance().clipboard().setText(self._name)
 
-        elif modifier == (QtCore.Qt.ControlModifier | QtCore.Qt.ShiftModifier) and key == QtCore.Qt.Key_C:
+        elif (
+            modifier == (QtCore.Qt.ControlModifier | QtCore.Qt.ShiftModifier)
+            and key == QtCore.Qt.Key_C
+        ):
             QtWidgets.QApplication.instance().clipboard().setText(
                 self.get_display_properties()
             )
 
-        elif modifier == (QtCore.Qt.ControlModifier | QtCore.Qt.ShiftModifier) and key == QtCore.Qt.Key_P:
+        elif (
+            modifier == (QtCore.Qt.ControlModifier | QtCore.Qt.ShiftModifier)
+            and key == QtCore.Qt.Key_P
+        ):
             info = QtWidgets.QApplication.instance().clipboard().text()
             try:
                 info = json.loads(info)
-                self.set_color(info['color'])
-                self.color_changed.emit(self.uuid, info['color'])
-                self.set_fmt(info['format'])
+                self.set_color(info["color"])
+                self.color_changed.emit(self.uuid, info["color"])
+                self.set_fmt(info["format"])
                 self.individual_axis.setCheckState(
-                    QtCore.Qt.Checked if info['individual_axis'] else QtCore.Qt.Unchecked
+                    QtCore.Qt.Checked
+                    if info["individual_axis"]
+                    else QtCore.Qt.Unchecked
                 )
                 self.ylink.setCheckState(
-                    QtCore.Qt.Checked if info['ylink'] else QtCore.Qt.Unchecked
+                    QtCore.Qt.Checked if info["ylink"] else QtCore.Qt.Unchecked
                 )
-                self.set_precision(info['precision'])
+                self.set_precision(info["precision"])
 
                 parent = self.parent().parent().parent().parent().parent()
                 sig, index = parent.plot.signal_by_uuid(self.uuid)
@@ -176,46 +196,52 @@ class ChannelDisplay(Ui_ChannelDiplay, QtWidgets.QWidget):
                 viewbox.setYRange(info["min"], info["max"], padding=0)
 
                 self.display.setCheckState(
-                    QtCore.Qt.Checked if info['display'] else QtCore.Qt.Unchecked
+                    QtCore.Qt.Checked if info["display"] else QtCore.Qt.Unchecked
                 )
 
                 self.ranges = {}
 
-                for key, val in info['ranges'].items():
-                    start, stop = [
-                        float(e)
-                        for e in key.split('|')
-                    ]
+                for key, val in info["ranges"].items():
+                    start, stop = [float(e) for e in key.split("|")]
                     self.ranges[(start, stop)] = val
 
             except:
                 pass
 
         else:
-            super().keyPressEvent(event)
+            event.ignore()
 
     def resizeEvent(self, event):
         width = self.name.size().width()
         if self.unit:
-            self.name.setText(self.fm.elidedText(f'{self._name} ({self.unit})', QtCore.Qt.ElideMiddle, width))
+            self.name.setText(
+                self.fm.elidedText(
+                    f"{self._name} ({self.unit})", QtCore.Qt.ElideMiddle, width
+                )
+            )
         else:
-            self.name.setText(self.fm.elidedText(self._name, QtCore.Qt.ElideMiddle, width))
+            self.name.setText(
+                self.fm.elidedText(self._name, QtCore.Qt.ElideMiddle, width)
+            )
 
     def text(self):
         return self._name
 
     def get_display_properties(self):
         info = {
-            'color': self.color,
-            'precision': self.precision,
-            'ylink': self.ylink.checkState() == QtCore.Qt.Checked,
-            'individual_axis': self.individual_axis.checkState() == QtCore.Qt.Checked,
-            'format': "hex" if self.fmt.startswith('0x') else "bin" if self.fmt.startswith('0b') else "phys",
-            'display': self.display.checkState() == QtCore.Qt.Checked,
-            'ranges': {
-                 f'{start}|{stop}': val
-                 for (start, stop), val in self.ranges.items()
-            }
+            "color": self.color,
+            "precision": self.precision,
+            "ylink": self.ylink.checkState() == QtCore.Qt.Checked,
+            "individual_axis": self.individual_axis.checkState() == QtCore.Qt.Checked,
+            "format": "hex"
+            if self.fmt.startswith("0x")
+            else "bin"
+            if self.fmt.startswith("0b")
+            else "phys",
+            "display": self.display.checkState() == QtCore.Qt.Checked,
+            "ranges": {
+                f"{start}|{stop}": val for (start, stop), val in self.ranges.items()
+            },
         }
 
         parent = self.parent().parent().parent().parent().parent()
@@ -224,7 +250,7 @@ class ChannelDisplay(Ui_ChannelDiplay, QtWidgets.QWidget):
 
         min_, max_ = parent.plot.view_boxes[index].viewRange()[1]
 
-        info['min'] = float(min_)
-        info['max'] = float(max_)
+        info["min"] = float(min_)
+        info["max"] = float(max_)
 
         return json.dumps(info)
