@@ -3,6 +3,8 @@ from functools import partial
 import os
 from pathlib import Path
 import webbrowser
+import gc
+from textwrap import wrap
 
 from PyQt5 import QtGui
 from PyQt5 import QtWidgets
@@ -11,26 +13,57 @@ import pyqtgraph as pg
 from natsort import natsorted
 
 from ...mdf import MDF, SUPPORTED_VERSIONS
+from ..dialogs.multi_search import MultiSearch
 from ..ui.main_window import Ui_PyMDFMainWindow
 from ...version import __version__ as libversion
 from ..utils import TERMINATED, run_thread_with_progress, setup_progress
 from .list import ListWidget
 from .file import FileWidget
 from .batch import BatchWidget
+from .plot import Plot
 
 
 class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
-
     def __init__(self, files=None, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.setupUi(self)
         self._settings = QtCore.QSettings()
         self._light_palette = self.palette()
 
-        self.ignore_value2text_conversions = self._settings.value('ignore_value2text_conversions', False, type=bool)
+        self.ignore_value2text_conversions = self._settings.value(
+            "ignore_value2text_conversions", False, type=bool
+        )
 
         self.batch = BatchWidget(self.ignore_value2text_conversions)
         self.stackedWidget.addWidget(self.batch)
+
+        widget = QtWidgets.QWidget()
+        layout = QtWidgets.QVBoxLayout()
+        widget.setLayout(layout)
+
+        multi_search = QtWidgets.QPushButton('Search')
+        icon = QtGui.QIcon()
+        icon.addPixmap(QtGui.QPixmap(":/search.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+        multi_search.setIcon(icon)
+        multi_search.clicked.connect(self.comparison_search)
+
+        multi_info = QtWidgets.QPushButton('Measurements information')
+        icon = QtGui.QIcon()
+        icon.addPixmap(QtGui.QPixmap(":/info.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+        multi_info.setIcon(icon)
+        multi_info.clicked.connect(self.comparison_info)
+
+        hbox = QtWidgets.QHBoxLayout()
+        hbox.addWidget(multi_search)
+        hbox.addWidget(multi_info)
+        hbox.addStretch()
+
+        self.comparison_plot = Plot({}, parent=self)
+
+        layout.addLayout(hbox)
+        layout.addWidget(self.comparison_plot)
+
+        self.stackedWidget.addWidget(widget)
         self.stackedWidget.setCurrentIndex(0)
 
         self.progress = None
@@ -44,6 +77,7 @@ class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         icon.addPixmap(QtGui.QPixmap(":/open.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
         action = QtWidgets.QAction(icon, "Open", menu)
         action.triggered.connect(self.open)
+        action.setShortcut(QtGui.QKeySequence("Ctrl+O"))
         open_group.addAction(action)
         menu.addActions(open_group.actions())
         action = QtWidgets.QAction(icon, "Open folder", menu)
@@ -66,6 +100,14 @@ class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         action.triggered.connect(partial(self.stackedWidget.setCurrentIndex, 1))
         mode_actions.addAction(action)
 
+        icon = QtGui.QIcon()
+        icon.addPixmap(
+            QtGui.QPixmap(":/compare.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off
+        )
+        action = QtWidgets.QAction(icon, "{: <20}".format("Comparison"), menu)
+        action.triggered.connect(partial(self.stackedWidget.setCurrentIndex, 2))
+        mode_actions.addAction(action)
+
         menu = QtWidgets.QMenu("Mode", self.menubar)
         menu.addActions(mode_actions.actions())
         self.menubar.addMenu(menu)
@@ -74,25 +116,25 @@ class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         self.menubar.addMenu(menu)
 
         # sub plots
-        subplot_action = QtWidgets.QAction('Sub-plots', menu)
+        subplot_action = QtWidgets.QAction("Sub-plots", menu)
         subplot_action.setCheckable(True)
 
-        state = self._settings.value('subplots', False, type=bool)
+        state = self._settings.value("subplots", False, type=bool)
         subplot_action.toggled.connect(self.set_subplot_option)
         subplot_action.triggered.connect(self.set_subplot_option)
         subplot_action.setChecked(state)
         menu.addAction(subplot_action)
 
         # Link sub-plots X-axis
-        subplot_action = QtWidgets.QAction('Link sub-plots X-axis', menu)
+        subplot_action = QtWidgets.QAction("Link sub-plots X-axis", menu)
         subplot_action.setCheckable(True)
-        state = self._settings.value('subplots_link', False, type=bool)
+        state = self._settings.value("subplots_link", False, type=bool)
         subplot_action.toggled.connect(self.set_subplot_link_option)
         subplot_action.setChecked(state)
         menu.addAction(subplot_action)
 
         # Link sub-plots X-axis
-        subplot_action = QtWidgets.QAction('Ignore value2text conversions', menu)
+        subplot_action = QtWidgets.QAction("Ignore value2text conversions", menu)
         subplot_action.setCheckable(True)
         subplot_action.toggled.connect(self.set_ignore_value2text_conversions_option)
         subplot_action.setChecked(self.ignore_value2text_conversions)
@@ -108,7 +150,7 @@ class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
             plot_background_option.addAction(action)
             action.triggered.connect(partial(self.set_plot_background, option))
 
-            if option == self._settings.value('plot_background', "Black"):
+            if option == self._settings.value("plot_background", "Black"):
                 action.setChecked(True)
                 action.triggered.emit()
 
@@ -126,7 +168,7 @@ class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
             theme_option.addAction(action)
             action.triggered.connect(partial(self.set_theme, option))
 
-            if option == self._settings.value('theme', "Light"):
+            if option == self._settings.value("theme", "Light"):
                 action.setChecked(True)
                 action.triggered.emit()
 
@@ -159,21 +201,27 @@ class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         plot_actions.addAction(action)
 
         icon = QtGui.QIcon()
-        icon.addPixmap(QtGui.QPixmap(":/list2.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+        icon.addPixmap(
+            QtGui.QPixmap(":/list2.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off
+        )
         action = QtWidgets.QAction(icon, "{: <20}\tS".format("Stack"), menu)
         action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key_S))
         action.setShortcut(QtCore.Qt.Key_S)
         plot_actions.addAction(action)
 
         icon = QtGui.QIcon()
-        icon.addPixmap(QtGui.QPixmap(":/zoom-in.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+        icon.addPixmap(
+            QtGui.QPixmap(":/zoom-in.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off
+        )
         action = QtWidgets.QAction(icon, "{: <20}\tI".format("Zoom in"), menu)
         action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key_I))
         action.setShortcut(QtCore.Qt.Key_I)
         plot_actions.addAction(action)
 
         icon = QtGui.QIcon()
-        icon.addPixmap(QtGui.QPixmap(":/zoom-out.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+        icon.addPixmap(
+            QtGui.QPixmap(":/zoom-out.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off
+        )
         action = QtWidgets.QAction(icon, "{: <20}\tO".format("Zoom out"), menu)
         action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key_O))
         action.setShortcut(QtCore.Qt.Key_O)
@@ -186,47 +234,70 @@ class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
 
         icon = QtGui.QIcon()
         icon.addPixmap(QtGui.QPixmap(":/plus.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
-        action = QtWidgets.QAction(icon, "{: <20}\tIns".format("Insert computation"), menu)
+        action = QtWidgets.QAction(
+            icon, "{: <20}\tIns".format("Insert computation"), menu
+        )
         action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key_Insert))
         action.setShortcut(QtCore.Qt.Key_Insert)
         plot_actions.addAction(action)
 
         icon = QtGui.QIcon()
         icon.addPixmap(QtGui.QPixmap(":/save.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
-        action = QtWidgets.QAction(icon, "{: <20}\tCtrl+S".format("Save active subplot channels"), menu)
-        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key_S, modifier=QtCore.Qt.ControlModifier))
+        action = QtWidgets.QAction(
+            icon, "{: <20}\tCtrl+S".format("Save active subplot channels"), menu
+        )
+        action.triggered.connect(
+            partial(
+                self.plot_action,
+                key=QtCore.Qt.Key_S,
+                modifier=QtCore.Qt.ControlModifier,
+            )
+        )
         action.setShortcut(QtGui.QKeySequence("Ctrl+S"))
         plot_actions.addAction(action)
 
         icon = QtGui.QIcon()
         icon.addPixmap(QtGui.QPixmap(":/save.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
-        action = QtWidgets.QAction(icon, "{: <20}\tCtrl+Shift+S".format("Save all subplot channels"), menu)
+        action = QtWidgets.QAction(
+            icon, "{: <20}\tCtrl+Shift+S".format("Save all subplot channels"), menu
+        )
         action.triggered.connect(self.save_all_subplots)
         action.setShortcut(QtGui.QKeySequence("Ctrl+Shift+S"))
         plot_actions.addAction(action)
 
-
         # values display
 
         display_format_actions = QtWidgets.QActionGroup(self)
 
         action = QtWidgets.QAction("{: <20}\tCtrl+H".format("Hex"), menu)
         action.triggered.connect(
-            partial(self.plot_action, key=QtCore.Qt.Key_H, modifier=QtCore.Qt.ControlModifier)
+            partial(
+                self.plot_action,
+                key=QtCore.Qt.Key_H,
+                modifier=QtCore.Qt.ControlModifier,
+            )
         )
         action.setShortcut(QtGui.QKeySequence("Ctrl+H"))
         display_format_actions.addAction(action)
 
         action = QtWidgets.QAction("{: <20}\tCtrl+B".format("Bin"), menu)
         action.triggered.connect(
-            partial(self.plot_action, key=QtCore.Qt.Key_B, modifier=QtCore.Qt.ControlModifier)
+            partial(
+                self.plot_action,
+                key=QtCore.Qt.Key_B,
+                modifier=QtCore.Qt.ControlModifier,
+            )
         )
         action.setShortcut(QtGui.QKeySequence("Ctrl+B"))
         display_format_actions.addAction(action)
 
         action = QtWidgets.QAction("{: <20}\tCtrl+P".format("Physical"), menu)
         action.triggered.connect(
-            partial(self.plot_action, key=QtCore.Qt.Key_P, modifier=QtCore.Qt.ControlModifier)
+            partial(
+                self.plot_action,
+                key=QtCore.Qt.Key_P,
+                modifier=QtCore.Qt.ControlModifier,
+            )
         )
         action.setShortcut(QtGui.QKeySequence("Ctrl+P"))
         display_format_actions.addAction(action)
@@ -247,23 +318,30 @@ class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         subs = QtWidgets.QActionGroup(self)
 
         action = QtWidgets.QAction("{: <20}\tShift+C".format("Cascade sub-plots"), menu)
-        action.triggered.connect(partial(self.show_sub_windows, mode='cascade'))
+        action.triggered.connect(partial(self.show_sub_windows, mode="cascade"))
         action.setShortcut(QtGui.QKeySequence("Shift+C"))
         subs.addAction(action)
 
-        action = QtWidgets.QAction("{: <20}\tShift+T".format("Tile sub-plots in a grid"), menu)
-        action.triggered.connect(partial(self.show_sub_windows, mode='tile'))
+        action = QtWidgets.QAction(
+            "{: <20}\tShift+T".format("Tile sub-plots in a grid"), menu
+        )
+        action.triggered.connect(partial(self.show_sub_windows, mode="tile"))
         action.setShortcut(QtGui.QKeySequence("Shift+T"))
         subs.addAction(action)
 
-        action = QtWidgets.QAction("{: <20}\tShift+V".format("Tile sub-plots vertically"), menu)
-        action.triggered.connect(partial(self.show_sub_windows, mode='tile vertically'))
+        action = QtWidgets.QAction(
+            "{: <20}\tShift+V".format("Tile sub-plots vertically"), menu
+        )
+        action.triggered.connect(partial(self.show_sub_windows, mode="tile vertically"))
         action.setShortcut(QtGui.QKeySequence("Shift+V"))
         subs.addAction(action)
 
-
-        action = QtWidgets.QAction("{: <20}\tShift+H".format("Tile sub-plots horizontally"), menu)
-        action.triggered.connect(partial(self.show_sub_windows, mode='tile horizontally'))
+        action = QtWidgets.QAction(
+            "{: <20}\tShift+H".format("Tile sub-plots horizontally"), menu
+        )
+        action.triggered.connect(
+            partial(self.show_sub_windows, mode="tile horizontally")
+        )
         action.setShortcut(QtGui.QKeySequence("Shift+H"))
         subs.addAction(action)
 
@@ -271,14 +349,18 @@ class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         cursors_actions = QtWidgets.QActionGroup(self)
 
         icon = QtGui.QIcon()
-        icon.addPixmap(QtGui.QPixmap(":/cursor.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+        icon.addPixmap(
+            QtGui.QPixmap(":/cursor.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off
+        )
         action = QtWidgets.QAction(icon, "{: <20}\tC".format("Cursor"), menu)
         action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key_C))
         action.setShortcut(QtCore.Qt.Key_C)
         cursors_actions.addAction(action)
 
         icon = QtGui.QIcon()
-        icon.addPixmap(QtGui.QPixmap(":/right.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+        icon.addPixmap(
+            QtGui.QPixmap(":/right.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off
+        )
         action = QtWidgets.QAction(icon, "{: <20}\t←".format("Move cursor left"), menu)
         action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key_Left))
         action.setShortcut(QtCore.Qt.Key_Left)
@@ -292,12 +374,23 @@ class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         cursors_actions.addAction(action)
 
         icon = QtGui.QIcon()
-        icon.addPixmap(QtGui.QPixmap(":/range.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+        icon.addPixmap(
+            QtGui.QPixmap(":/range.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off
+        )
         action = QtWidgets.QAction(icon, "{: <20}\tR".format("Range"), menu)
         action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key_R))
         action.setShortcut(QtCore.Qt.Key_R)
         cursors_actions.addAction(action)
 
+        icon = QtGui.QIcon()
+        icon.addPixmap(
+            QtGui.QPixmap(":/lock_range.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off
+        )
+        action = QtWidgets.QAction(icon, "{: <20}\tY".format("Lock/unlock range"), menu)
+        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key_Y))
+        action.setShortcut(QtCore.Qt.Key_Y)
+        cursors_actions.addAction(action)
+
         self.plot_menu = QtWidgets.QMenu("Plot", self.menubar)
         self.plot_menu.addActions(plot_actions.actions())
         self.plot_menu.addSeparator()
@@ -317,8 +410,11 @@ class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         open_group.addAction(action)
         menu.addActions(open_group.actions())
 
-        self.with_dots = self._settings.value('dots', False, type=bool)
-        self.setWindowTitle(f'asammdf {libversion} - Single files')
+        self.with_dots = self._settings.value("dots", False, type=bool)
+        self.setWindowTitle(f"asammdf {libversion} [PID={os.getpid()}] - Single files")
+
+        self.set_subplot_option(self._settings.value("subplots", "Disabled"))
+        self.set_subplot_link_option(self._settings.value("subplots_link", "Disabled"))
 
         if files:
             for name in files:
@@ -328,11 +424,8 @@ class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
 
         self.show()
 
-        self.set_subplot_option(self._settings.value('subplots', "Disabled"))
-        self.set_subplot_link_option(self._settings.value('subplots_link', "Disabled"))
-
     def help(self, event):
-        webbrowser.open_new(r'http://asammdf.readthedocs.io/en/master/gui.html')
+        webbrowser.open_new(r"http://asammdf.readthedocs.io/en/master/gui.html")
 
     def save_all_subplots(self, key):
         widget = self.files.currentWidget()
@@ -340,37 +433,42 @@ class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
 
     def plot_action(self, key, modifier=QtCore.Qt.NoModifier):
         event = QtGui.QKeyEvent(QtCore.QEvent.KeyPress, key, modifier)
-        widget = self.files.currentWidget()
-        if widget and widget.get_current_plot():
-            widget.get_current_plot().keyPressEvent(event)
+        if self.stackedWidget.currentIndex() == 0:
+            widget = self.files.currentWidget()
+            if widget and widget.get_current_plot():
+                widget.get_current_plot().keyPressEvent(event)
+        elif self.stackedWidget.currentIndex() == 2:
+            self.comparison_plot.keyPressEvent(event)
 
     def toggle_dots(self, key):
         self.with_dots = not self.with_dots
-        self._settings.setValue('dots', self.with_dots)
+        self._settings.setValue("dots", self.with_dots)
 
         count = self.files.count()
 
         for i in range(count):
             self.files.widget(i).set_line_style(with_dots=self.with_dots)
 
+        self.comparison_plot.plot.update_lines(with_dots=self.with_dots)
+
     def show_sub_windows(self, mode):
 
         widget = self.files.currentWidget()
         if widget:
-            if mode == 'tile':
+            if mode == "tile":
                 widget.mdi_area.tileSubWindows()
-            elif mode == 'cascade':
+            elif mode == "cascade":
                 widget.mdi_area.cascadeSubWindows()
-            elif mode == 'tile vertically':
+            elif mode == "tile vertically":
                 widget.mdi_area.tile_vertically()
-            elif mode == 'tile horizontally':
+            elif mode == "tile horizontally":
                 widget.mdi_area.tile_horizontally()
 
     def set_subplot_option(self, state):
         if isinstance(state, str):
-            state = True if state == 'true' else False
+            state = True if state == "true" else False
         self.subplots = state
-        self._settings.setValue('subplots', state)
+        self._settings.setValue("subplots", state)
 
         count = self.files.count()
 
@@ -378,18 +476,18 @@ class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
             self.files.widget(i).set_subplots(state)
 
     def set_plot_background(self, option):
-        self._settings.setValue('plot_background', option)
-        if option == 'Black':
-            pg.setConfigOption('background', 'k')
-            pg.setConfigOption('foreground', 'w')
+        self._settings.setValue("plot_background", option)
+        if option == "Black":
+            pg.setConfigOption("background", "k")
+            pg.setConfigOption("foreground", "w")
         else:
-            pg.setConfigOption('background', 'w')
-            pg.setConfigOption('foreground', 'k')
+            pg.setConfigOption("background", "w")
+            pg.setConfigOption("foreground", "k")
 
     def set_theme(self, option):
-        self._settings.setValue('theme', option)
+        self._settings.setValue("theme", option)
         app = QtWidgets.QApplication.instance()
-        if option == 'Light':
+        if option == "Light":
             app.setPalette(self._light_palette)
         else:
 
@@ -477,7 +575,9 @@ class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
             palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Shadow, brush)
             brush = QtGui.QBrush(QtGui.QColor(27, 27, 27))
             brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.AlternateBase, brush)
+            palette.setBrush(
+                QtGui.QPalette.Inactive, QtGui.QPalette.AlternateBase, brush
+            )
             brush = QtGui.QBrush(QtGui.QColor(255, 255, 220))
             brush.setStyle(QtCore.Qt.SolidPattern)
             palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.ToolTipBase, brush)
@@ -522,7 +622,9 @@ class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
             palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Shadow, brush)
             brush = QtGui.QBrush(QtGui.QColor(55, 55, 55))
             brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.AlternateBase, brush)
+            palette.setBrush(
+                QtGui.QPalette.Disabled, QtGui.QPalette.AlternateBase, brush
+            )
             brush = QtGui.QBrush(QtGui.QColor(255, 255, 220))
             brush.setStyle(QtCore.Qt.SolidPattern)
             palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.ToolTipBase, brush)
@@ -536,9 +638,9 @@ class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
 
     def set_subplot_link_option(self, state):
         if isinstance(state, str):
-            state = True if state == 'true' else False
+            state = True if state == "true" else False
         self.subplots_link = state
-        self._settings.setValue('subplots_link', state)
+        self._settings.setValue("subplots_link", state)
         count = self.files.count()
 
         for i in range(count):
@@ -546,9 +648,9 @@ class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
 
     def set_ignore_value2text_conversions_option(self, state):
         if isinstance(state, str):
-            state = True if state == 'true' else False
+            state = True if state == "true" else False
         self.ignore_value2text_conversions = state
-        self._settings.setValue('ignore_value2text_conversions', state)
+        self._settings.setValue("ignore_value2text_conversions", state)
         count = self.files.count()
 
         for i in range(count):
@@ -572,14 +674,17 @@ class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
             count = self.batch.files_list.count()
 
             icon = QtGui.QIcon()
-            icon.addPixmap(QtGui.QPixmap(":/file.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+            icon.addPixmap(
+                QtGui.QPixmap(":/file.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off
+            )
 
             for row in range(count):
                 self.batch.files_list.item(row).setIcon(icon)
 
     def open(self, event):
-        if self.stackedWidget.currentIndex() == 0:
+        if self.stackedWidget.currentIndex() in (0, 2):
             self.open_file(event)
+            self.stackedWidget.setCurrentIndex(0)
         else:
             self.open_batch_files(event)
 
@@ -608,35 +713,46 @@ class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         file_names, _ = QtWidgets.QFileDialog.getOpenFileNames(
             self,
             "Select measurement file",
-            "",
+            self._settings.value("last_opened_path", "", str),
             "MDF v3 (*.dat *.mdf);;MDF v4(*.mf4);;DL3/ERG files (*.dl3 *.erg);;All files (*.dat *.mdf *.mf4 *.dl3 *.erg)",
             "All files (*.dat *.mdf *.mf4 *.dl3 *.erg)",
         )
 
+        if file_names:
+            self._settings.setValue("last_opened_path", file_names[0])
+            gc.collect()
+
         for file_name in natsorted(file_names):
             self._open_file(file_name)
 
     def open_folder(self, event):
+
         folder = QtWidgets.QFileDialog.getExistingDirectory(
             self,
             "Select folder",
             "",
-            QtWidgets.QFileDialog.ShowDirsOnly | QtWidgets.QFileDialog.DontResolveSymlinks,
+            QtWidgets.QFileDialog.ShowDirsOnly
+            | QtWidgets.QFileDialog.DontResolveSymlinks,
         )
         if not folder:
             return
+
+        gc.collect()
+
         if self.stackedWidget.currentIndex() == 0:
             for root, dirs, files in os.walk(folder):
                 for file in natsorted(files):
-                    if file.lower().endswith(('.erg', '.dl3', '.dat', '.mdf', '.mf4')):
+                    if file.lower().endswith((".erg", ".dl3", ".dat", ".mdf", ".mf4")):
                         self._open_file(os.path.join(root, file))
         else:
             icon = QtGui.QIcon()
-            icon.addPixmap(QtGui.QPixmap(":/file.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+            icon.addPixmap(
+                QtGui.QPixmap(":/file.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off
+            )
 
             for root, dirs, files in os.walk(folder):
                 for file in natsorted(files):
-                    if file.lower().endswith(('.erg', '.dl3', '.dat', '.mdf', '.mf4')):
+                    if file.lower().endswith((".erg", ".dl3", ".dat", ".mdf", ".mf4")):
 
                         row = self.batch.files_list.count()
                         self.batch.files_list.addItem(os.path.join(root, file))
@@ -665,17 +781,19 @@ class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         try:
             if self.stackedWidget.currentIndex() == 0:
                 for path in e.mimeData().text().splitlines():
-                    path = Path(path.replace(r'file:///', ''))
-                    if path.suffix.lower() in ('.dat', '.mdf', '.mf4'):
+                    path = Path(path.replace(r"file:///", ""))
+                    if path.suffix.lower() in (".dat", ".mdf", ".mf4"):
 
                         self._open_file(path)
             else:
                 icon = QtGui.QIcon()
-                icon.addPixmap(QtGui.QPixmap(":/file.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+                icon.addPixmap(
+                    QtGui.QPixmap(":/file.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off
+                )
 
                 for path in e.mimeData().text().splitlines():
-                    path = Path(path.replace(r'file:///', ''))
-                    if path.suffix.lower() in ('.dat', '.mdf', '.mf4'):
+                    path = Path(path.replace(r"file:///", ""))
+                    if path.suffix.lower() in (".dat", ".mdf", ".mf4"):
 
                         row = self.batch.files_list.count()
                         self.batch.files_list.addItem(str(path))
@@ -686,10 +804,19 @@ class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
     def mode_changed(self, index):
         if index == 0:
             self.plot_menu.setEnabled(True)
-            self.setWindowTitle(f'asammdf {libversion} - Single files')
-        else:
+            self.setWindowTitle(
+                f"asammdf {libversion} [PID={os.getpid()}] - Single files"
+            )
+        elif index == 1:
             self.plot_menu.setEnabled(False)
-            self.setWindowTitle(f'asammdf {libversion} - Batch processing')
+            self.setWindowTitle(
+                f"asammdf {libversion} [PID={os.getpid()}] - Batch processing"
+            )
+        elif index == 2:
+            self.plot_menu.setEnabled(True)
+            self.setWindowTitle(
+                f"asammdf {libversion} [PID={os.getpid()}] - Comparison"
+            )
 
     def keyPressEvent(self, event):
         key = event.key()
@@ -698,5 +825,69 @@ class MainWindow(Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         if key == QtCore.Qt.Key_F and modifier == QtCore.Qt.ControlModifier:
             if self.files.count() and self.stackedWidget.currentIndex() == 0:
                 self.files.currentWidget().keyPressEvent(event)
+            elif self.files.count() and self.stackedWidget.currentIndex() == 2:
+                count = self.files.count()
+                channels_dbs = [
+                    self.files.widget(i).mdf.channels_db for i in range(count)
+                ]
+                measurements = [
+                    str(self.files.widget(i).mdf.name)
+                    for i in range(count)
+                ]
+
+                dlg = MultiSearch(channels_dbs, measurements, parent=self,)
+                dlg.setModal(True)
+                dlg.exec_()
+                result = dlg.result
+                if result:
+                    selections = {}
+                    for file_index, (group_index, channel_index) in result:
+                        if file_index not in selections:
+                            selections[file_index] = []
+                        selections[file_index].append(
+                            (None, group_index, channel_index)
+                        )
+                    new_signals = []
+                    for file_index in sorted(selections):
+                        channels = selections[file_index]
+                        signals = self.files.widget(file_index).mdf.select(
+                            channels,
+                            copy_master=False,
+                            ignore_value2text_conversions=self.ignore_value2text_conversions,
+                        )
+                        for sig, entry in zip(signals, channels):
+                            sig.tooltip = f"{sig.name}\n@ {self.files.widget(file_index).file_name}"
+                            sig.name = f"{file_index+1}: {sig.name}"
+                            sig.group_index = entry[1]
+                            sig.channel_index = entry[2]
+                        new_signals.extend(signals)
+
+                    self.comparison_plot.add_new_channels(new_signals)
+
         else:
             super().keyPressEvent(event)
+
+    def comparison_search(self, event):
+        event = QtGui.QKeyEvent(
+            QtCore.QEvent.KeyPress, QtCore.Qt.Key_F, QtCore.Qt.ControlModifier
+        )
+        self.keyPressEvent(event)
+
+    def comparison_info(self, event):
+        count = self.files.count()
+        measurements = [
+            str(self.files.widget(i).mdf.name)
+            for i in range(count)
+        ]
+
+        info = []
+        for i, name in enumerate(measurements, 1):
+            info.extend(wrap(f'{i:> 2}: {name}', 120))
+
+        QtWidgets.QMessageBox.information(
+            self,
+            "Measurement files used for comparison",
+            '\n'.join(info),
+        )
+
+
