@@ -2,6 +2,7 @@
 import random
 import unittest
 import urllib
+import urllib.request
 import numexpr
 from zipfile import ZipFile
 import tempfile
@@ -11,10 +12,7 @@ from io import BytesIO
 import numpy as np
 
 from .utils import (
-    CHANNELS_DEMO,
-    CHANNELS_ARRAY,
     cycles,
-    channels_count,
     generate_test_file,
     generate_arrays_test_file,
 )
@@ -22,7 +20,7 @@ from asammdf import MDF, Signal, SUPPORTED_VERSIONS
 from asammdf.blocks.utils import MdfException
 from pandas import DataFrame
 
-SUPPORTED_VERSIONS = [version for version in SUPPORTED_VERSIONS if version >= "4.00"]
+SUPPORTED_VERSIONS = [version for version in SUPPORTED_VERSIONS if "4.20" > version >= "3.20" ]
 
 CHANNEL_LEN = 100000
 
@@ -40,7 +38,7 @@ class TestMDF(unittest.TestCase):
     @classmethod
     def setUpClass(cls):
 
-        url = "https://github.com/danielhrisca/asammdf/files/3111848/test.demo.zip"
+        url = "https://github.com/danielhrisca/asammdf/files/4078993/test.demo.zip"
         urllib.request.urlretrieve(url, "test.zip")
 
         cls.tempdir_demo = tempfile.TemporaryDirectory()
@@ -56,12 +54,14 @@ class TestMDF(unittest.TestCase):
         generate_arrays_test_file(cls.tempdir_array.name)
 
     def test_mdf_header(self):
-        mdf = BytesIO(b'M' * 100)
+        mdf = BytesIO(b"M" * 100)
         with self.assertRaises(MdfException):
             MDF(mdf)
 
     def test_wrong_header_version(self):
-        mdf = BytesIO(b'MDF     AAAA    amdf500d\x00\x00\x00\x00\x9f\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00')
+        mdf = BytesIO(
+            b"MDF     AAAA    amdf500d\x00\x00\x00\x00\x9f\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
+        )
         with self.assertRaises(MdfException):
             MDF(mdf)
 
@@ -138,7 +138,9 @@ class TestMDF(unittest.TestCase):
 
                         elif i == 6:
                             for j in range(1, 20):
-                                target = np.array([b'Value %d' % j for _ in range(cycles)])
+                                target = np.array(
+                                    [b"Value %d" % j for _ in range(cycles)]
+                                )
                                 vals = mdf.get(group=i, index=j + 1, samples_only=True)[
                                     0
                                 ]
@@ -148,7 +150,6 @@ class TestMDF(unittest.TestCase):
                                 self.assertTrue(cond)
             self.assertTrue(equal)
 
-
     def test_read_arrays(self):
         print("MDF read big array files")
         for input_file in Path(TestMDF.tempdir_array.name).iterdir():
@@ -253,50 +254,35 @@ class TestMDF(unittest.TestCase):
 
         print("MDF read tests")
 
-        ret = True
+        mdf_files = [
+            file
+            for file in Path(TestMDF.tempdir_demo.name).iterdir()
+            if file.suffix in ('.mdf', '.mf4')
+        ]
 
-        for enable in (True, False):
-            for mdf in Path(TestMDF.tempdir_demo.name).iterdir():
+        signals = [
+            file
+            for file in Path(TestMDF.tempdir_demo.name).iterdir()
+            if file.suffix == '.npy'
+        ]
 
-                for inp in (mdf, BytesIO(mdf.read_bytes())):
+        for file in mdf_files:
+            print(file)
 
-                    with MDF(inp) as input_file:
-                        if input_file.version == "2.00":
-                            continue
-                        print(mdf)
-                        for name in set(input_file.channels_db) - {"time", "t"}:
+            for inp in (file, BytesIO(file.read_bytes())):
 
-                            if (
-                                name.endswith("[0]")
-                                or name.startswith("DI")
-                                or "\\" in name
-                            ):
-                                continue
-                            signal = input_file.get(name)
+                with MDF(inp, use_display_names=True) as input_file:
 
-                            try:
-                                original_samples = CHANNELS_DEMO[name.split("\\")[0]]
-                            except:
-                                print(name)
-                                raise
-                            if signal.samples.dtype.kind == "f":
-                                signal = signal.astype(np.float32)
-                            res = np.array_equal(signal.samples, original_samples)
-                            if not res:
-                                raw = input_file.get(name, raw=True).samples
+                    for signal in signals:
+                        name = signal.stem
+                        target = np.load(signal)
+                        values = input_file.get(name).samples
 
-                                print(repr(signal.samples))
-                                ret = False
-                                print(name, *zip(raw, signal.samples, original_samples), sep='\n')
-                                1/0
-
-        self.assertTrue(ret)
+                        self.assertTrue(np.array_equal(target, values))
 
     def test_convert(self):
         print("MDF convert big files tests")
 
-        t = np.arange(cycles, dtype=np.float64)
-
         for out in SUPPORTED_VERSIONS:
             for input_file in Path(TestMDF.tempdir_general.name).iterdir():
                 for compression in range(3):
@@ -403,7 +389,9 @@ class TestMDF(unittest.TestCase):
 
                             elif i == 6:
                                 for j in range(1, 20):
-                                    target = np.array([b'Value %d' % j for _ in range(cycles)])
+                                    target = np.array(
+                                        [b"Value %d" % j for _ in range(cycles)]
+                                    )
                                     vals = mdf.get(
                                         group=i, index=j + 1, samples_only=True
                                     )[0]
@@ -418,38 +406,41 @@ class TestMDF(unittest.TestCase):
                     self.assertTrue(equal)
 
     def test_convert_demo(self):
-        print("MDF convert tests")
+        print("MDF convert demo tests")
 
-        for out in SUPPORTED_VERSIONS:
-            for input_file in Path(TestMDF.tempdir_demo.name).iterdir():
-                if MDF(input_file).version == "2.00":
-                    continue
-                print(input_file, out)
-                with MDF(input_file) as mdf:
-                    outfile = mdf.convert(out).save(
-                        Path(TestMDF.tempdir_demo.name) / "tmp",
-                        overwrite=True,
+        mdf_files = [
+            file
+            for file in Path(TestMDF.tempdir_demo.name).iterdir()
+            if file.suffix in ('.mdf', '.mf4')
+        ]
+
+        signals = [
+            file
+            for file in Path(TestMDF.tempdir_demo.name).iterdir()
+            if file.suffix == '.npy'
+        ]
+
+        for file in mdf_files:
+
+            for inp in (file, BytesIO(file.read_bytes())):
+
+                with MDF(inp, use_display_names=True) as input_file:
+
+                    for out in SUPPORTED_VERSIONS:
+                        print(file, out, type(inp))
+
+                    outfile = input_file.convert(out).save(
+                        Path(TestMDF.tempdir_demo.name) / "tmp", overwrite=True,
                     )
 
-                equal = True
+                    with MDF(outfile, use_display_names=True) as mdf:
 
-                with MDF(input_file) as mdf, MDF(outfile) as mdf2:
+                        for signal in signals:
+                            name = signal.stem
+                            target = np.load(signal)
+                            values = mdf.get(name).samples
 
-                    for name in set(mdf2.channels_db) - {"t", "time"}:
-                        original = mdf.get(name)
-                        converted = mdf2.get(name)
-                        raw = mdf.get(name, raw=True)
-                        if not np.array_equal(original.samples, converted.samples):
-                            equal = False
-                            print(name, *zip(raw.samples, original.samples, converted.samples), outfile, sep='\n')
-                            1 / 0
-                        if not np.array_equal(
-                            original.timestamps, converted.timestamps
-                        ):
-                            equal = False
-                            1 / 0
-
-                self.assertTrue(equal)
+                            self.assertTrue(np.array_equal(target, values))
 
     def test_cut(self):
         print("MDF cut big files tests")
@@ -463,35 +454,47 @@ class TestMDF(unittest.TestCase):
 
                     outfile0 = MDF(input_file)
                     outfile0.configure(read_fragment_size=8000)
-                    outfile0 = outfile0.cut(stop=-1, whence=whence, include_ends=False).save(
-                        Path(TestMDF.tempdir.name) / "tmp0", overwrite=True,
+                    outfile0 = outfile0.cut(
+                        stop=-1, whence=whence, include_ends=False
+                    ).save(
+                        Path(TestMDF.tempdir.name) / "tmp0",
+                        overwrite=True,
                         compression=compression,
                     )
 
                     outfile1 = MDF(input_file)
                     outfile1.configure(read_fragment_size=8000)
-                    outfile1 = outfile1.cut(stop=105, whence=whence, include_ends=False).save(
-                        Path(TestMDF.tempdir.name) / "tmp1", overwrite=True,
+                    outfile1 = outfile1.cut(
+                        stop=105, whence=whence, include_ends=False
+                    ).save(
+                        Path(TestMDF.tempdir.name) / "tmp1",
+                        overwrite=True,
                         compression=compression,
                     )
 
                     outfile2 = MDF(input_file)
                     outfile2.configure(read_fragment_size=8000)
-                    outfile2 = outfile2.cut(start=105.1, stop=201, whence=whence, include_ends=False).save(
-                        Path(TestMDF.tempdir.name) / "tmp2", overwrite=True,
+                    outfile2 = outfile2.cut(
+                        start=105.1, stop=201, whence=whence, include_ends=False
+                    ).save(
+                        Path(TestMDF.tempdir.name) / "tmp2",
+                        overwrite=True,
                         compression=compression,
                     )
 
                     outfile3 = MDF(input_file)
                     outfile3.configure(read_fragment_size=8000)
-                    outfile3 = outfile3.cut(start=201.1, whence=whence, include_ends=False).save(
-                        Path(TestMDF.tempdir.name) / "tmp3", overwrite=True
-                    )
+                    outfile3 = outfile3.cut(
+                        start=201.1, whence=whence, include_ends=False
+                    ).save(Path(TestMDF.tempdir.name) / "tmp3", overwrite=True)
 
                     outfile4 = MDF(input_file)
                     outfile4.configure(read_fragment_size=8000)
-                    outfile4 = outfile4.cut(start=7000, whence=whence, include_ends=False).save(
-                        Path(TestMDF.tempdir.name) / "tmp4", overwrite=True,
+                    outfile4 = outfile4.cut(
+                        start=7000, whence=whence, include_ends=False
+                    ).save(
+                        Path(TestMDF.tempdir.name) / "tmp4",
+                        overwrite=True,
                         compression=compression,
                     )
 
@@ -499,8 +502,11 @@ class TestMDF(unittest.TestCase):
                         [outfile0, outfile1, outfile2, outfile3, outfile4],
                         version=MDF(input_file).version,
                         sync=whence,
-                    ).save(Path(TestMDF.tempdir.name) / "tmp_cut", overwrite=True,
-                        compression=compression,)
+                    ).save(
+                        Path(TestMDF.tempdir.name) / "tmp_cut",
+                        overwrite=True,
+                        compression=compression,
+                    )
 
                     with MDF(outfile) as mdf:
 
@@ -595,7 +601,9 @@ class TestMDF(unittest.TestCase):
 
                             elif i == 6:
                                 for j in range(1, 20):
-                                    target = np.array([b'Value %d' % j for _ in range(cycles)])
+                                    target = np.array(
+                                        [b"Value %d" % j for _ in range(cycles)]
+                                    )
                                     vals = mdf.get(
                                         group=i, index=j + 1, samples_only=True
                                     )[0]
@@ -614,9 +622,9 @@ class TestMDF(unittest.TestCase):
 
                 outfile1 = MDF(input_file)
                 outfile1.configure(read_fragment_size=8000)
-                outfile1 = outfile1.cut(stop=105.5, whence=whence, include_ends=False).save(
-                    Path(TestMDF.tempdir.name) / "tmp1", overwrite=True
-                )
+                outfile1 = outfile1.cut(
+                    stop=105.5, whence=whence, include_ends=False
+                ).save(Path(TestMDF.tempdir.name) / "tmp1", overwrite=True)
                 outfile2 = MDF(input_file)
                 outfile2.configure(read_fragment_size=8000)
                 outfile2 = outfile2.cut(
@@ -624,13 +632,12 @@ class TestMDF(unittest.TestCase):
                 ).save(Path(TestMDF.tempdir.name) / "tmp2", overwrite=True)
                 outfile3 = MDF(input_file)
                 outfile3.configure(read_fragment_size=8000)
-                outfile3 = outfile3.cut(start=201.5, whence=whence, include_ends=False).save(
-                    Path(TestMDF.tempdir.name) / "tmp3", overwrite=True
-                )
+                outfile3 = outfile3.cut(
+                    start=201.5, whence=whence, include_ends=False
+                ).save(Path(TestMDF.tempdir.name) / "tmp3", overwrite=True)
 
                 outfile = MDF.concatenate(
-                    [outfile1, outfile2, outfile3],
-                    MDF(input_file).version
+                    [outfile1, outfile2, outfile3], MDF(input_file).version
                 ).save(Path(TestMDF.tempdir.name) / "tmp_cut", overwrite=True)
 
                 equal = True
@@ -658,14 +665,10 @@ class TestMDF(unittest.TestCase):
                                 types = np.dtype(types)
 
                                 vals = mdf.get(
-                                    "Channel_{}".format(j),
-                                    group=i,
-                                    samples_only=True,
+                                    "Channel_{}".format(j), group=i, samples_only=True,
                                 )[0]
                                 target = [arr * j for arr in samples]
-                                target = np.core.records.fromarrays(
-                                    target, dtype=types
-                                )
+                                target = np.core.records.fromarrays(target, dtype=types)
                                 if not np.array_equal(vals, target):
                                     equal = False
                                     print(
@@ -691,14 +694,10 @@ class TestMDF(unittest.TestCase):
                                 types = np.dtype(types)
 
                                 vals = mdf.get(
-                                    "Channel_{}".format(j),
-                                    group=i,
-                                    samples_only=True,
+                                    "Channel_{}".format(j), group=i, samples_only=True,
                                 )[0]
                                 target = [samples * j]
-                                target = np.core.records.fromarrays(
-                                    target, dtype=types
-                                )
+                                target = np.core.records.fromarrays(target, dtype=types)
                                 if not np.array_equal(vals, target):
                                     equal = False
                                     1 / 0
@@ -731,14 +730,10 @@ class TestMDF(unittest.TestCase):
                                 types = np.dtype(types)
 
                                 vals = mdf.get(
-                                    "Channel_{}".format(j),
-                                    group=i,
-                                    samples_only=True,
+                                    "Channel_{}".format(j), group=i, samples_only=True,
                                 )[0]
                                 target = [arr * j for arr in samples]
-                                target = np.core.records.fromarrays(
-                                    target, dtype=types
-                                )
+                                target = np.core.records.fromarrays(target, dtype=types)
                                 if not np.array_equal(vals, target):
                                     equal = False
                                     1 / 0
@@ -746,159 +741,168 @@ class TestMDF(unittest.TestCase):
             self.assertTrue(equal)
 
     def test_cut_demo(self):
-        print("MDF cut absolute tests")
+        print("MDF cut demo tests")
 
-        for input_file in Path(TestMDF.tempdir_demo.name).iterdir():
+        mdf_files = [
+            file
+            for file in Path(TestMDF.tempdir_demo.name).iterdir()
+            if file.suffix in ('.mdf', '.mf4')
+        ]
 
-            if "2.00" in input_file.name:
-                continue
-            for whence in (0, 1):
-                print(input_file, whence)
+        signals = [
+            file
+            for file in Path(TestMDF.tempdir_demo.name).iterdir()
+            if file.suffix == '.npy'
+        ]
 
-                outfile1 = (
-                    MDF(input_file)
-                    .cut(stop=2, whence=whence, include_ends=False)
-                    .save(Path(TestMDF.tempdir.name) / "tmp1", overwrite=True)
-                )
-                outfile2 = (
-                    MDF(input_file)
-                    .cut(start=2, stop=6, whence=whence, include_ends=False)
-                    .save(Path(TestMDF.tempdir.name) / "tmp2", overwrite=True)
-                )
-                outfile3 = (
-                    MDF(input_file)
-                    .cut(start=6, whence=whence, include_ends=False)
-                    .save(Path(TestMDF.tempdir.name) / "tmp3", overwrite=True)
-                )
+        for file in mdf_files:
+            print(file)
 
-                outfile = MDF.concatenate(
-                    [outfile1, outfile2, outfile3],
-                    version=MDF(input_file).version
-                ).save(Path(TestMDF.tempdir.name) / "tmp", overwrite=True)
+            for inp in (file, BytesIO(file.read_bytes())):
 
-                print("OUT", outfile)
+                with MDF(inp, use_display_names=True) as input_file:
 
-                equal = True
+                    for whence in (0, 1):
+                        print(file, whence)
 
-                with MDF(input_file) as mdf, MDF(
-                    outfile) as mdf2:
+                        outfile1 = (
+                            input_file
+                            .cut(stop=2, whence=whence, include_ends=False)
+                            .save(Path(TestMDF.tempdir.name) / "tmp1", overwrite=True)
+                        )
+                        outfile2 = (
+                            input_file
+                            .cut(start=2, stop=6, whence=whence, include_ends=False)
+                            .save(Path(TestMDF.tempdir.name) / "tmp2", overwrite=True)
+                        )
+                        outfile3 = (
+                            input_file
+                            .cut(start=6, whence=whence, include_ends=False)
+                            .save(Path(TestMDF.tempdir.name) / "tmp3", overwrite=True)
+                        )
 
-                    for i, group in enumerate(mdf.groups):
-                        for j, _ in enumerate(group["channels"][1:], 1):
-                            original = mdf.get(group=i, index=j)
-                            converted = mdf2.get(group=i, index=j)
-                            if not np.array_equal(
-                                original.samples, converted.samples
-                            ):
-                                equal = False
-                            if not np.array_equal(
-                                original.timestamps, converted.timestamps
-                            ):
-                                equal = False
+                        outfile = MDF.concatenate(
+                            [outfile1, outfile2, outfile3], version=input_file.version,
+                            use_display_names=True,
+                        ).save(Path(TestMDF.tempdir.name) / "tmp", overwrite=True)
 
-                self.assertTrue(equal)
+                        print("OUT", outfile)
+
+                        with MDF(outfile, use_display_names=True) as mdf2:
+
+                            for signal in signals:
+                                target = np.load(signal)
+                                sig = mdf2.get(signal.stem)
+                                timestamps = input_file.get(signal.stem).timestamps
+
+                                self.assertTrue(np.array_equal(sig.samples, target))
+                                self.assertTrue(np.array_equal(timestamps, sig.timestamps))
 
     def test_filter(self):
-        print("MDF filter tests")
 
-        for input_file in Path(TestMDF.tempdir_demo.name).iterdir():
+        print("MDF read tests")
 
-            if MDF(input_file).version <= "2.00":
-                # if MDF(input_file, memory=memory).version < '4.00':
-                continue
+        mdf_files = [
+            file
+            for file in Path(TestMDF.tempdir_demo.name).iterdir()
+            if file.suffix in ('.mdf', '.mf4')
+        ]
 
-            channels_nr = np.random.randint(1, len(CHANNELS_DEMO) + 1)
+        signals = {
+            file.stem: file
+            for file in Path(TestMDF.tempdir_demo.name).iterdir()
+            if file.suffix == '.npy'
+        }
 
-            channel_list = random.sample(list(CHANNELS_DEMO), channels_nr)
+        for file in mdf_files:
+            print(file)
 
-            filtered_mdf = MDF(input_file).filter(
-                channel_list)
+            for inp in (file, BytesIO(file.read_bytes())):
 
-            target = set(
-                k
-                for k in filtered_mdf.channels_db
-                if not k.endswith("[0]")
-                and not k.startswith("DI")
-                and "\\" not in k
-            )
+                with MDF(inp, use_display_names=True) as input_file:
 
-            self.assertTrue((target - {"t", "time"}) == set(channel_list))
+                    names = [
+                        ch.name
+                        for gp in input_file.groups
+                        for ch in gp.channels[1:]
+                    ]
 
-            equal = True
+                    channels_nr = np.random.randint(1, len(names) + 1)
 
-            with MDF(input_file) as mdf:
-                print(input_file)
-                names = list(channel_list)
-                for name in channel_list:
-                    self.assertTrue(name in mdf)
+                    channel_list = random.sample(names, channels_nr)
 
-                names = [name + '_' for name in names]
-                for name in names:
-                    self.assertFalse(name in mdf)
+                    filtered_mdf = input_file.filter(channel_list)
 
-                names = [name[:-3] for name in names]
-                for name in names:
-                    self.assertFalse(name in mdf)
+                    target_names = set(filtered_mdf.channels_db)
 
-                for name in channel_list:
-                    original = mdf.get(name)
-                    filtered = filtered_mdf.get(name)
-                    if not np.array_equal(original.samples, filtered.samples):
-                        equal = False
-                    if not np.array_equal(original.timestamps, filtered.timestamps):
-                        equal = False
 
-            self.assertTrue(equal)
+                    self.assertFalse(set(channel_list) - (target_names - {'time'}))
+
+                    for name in channel_list:
+                        target = np.load(signals[name])
+                        filtered = filtered_mdf.get(name)
+                        self.assertTrue(np.array_equal(target, filtered.samples))
 
     def test_select(self):
         print("MDF select tests")
 
-        for input_file in Path(TestMDF.tempdir_demo.name).iterdir():
+        mdf_files = [
+            file
+            for file in Path(TestMDF.tempdir_demo.name).iterdir()
+            if file.suffix in ('.mdf', '.mf4')
+        ]
 
-            if MDF(input_file).version == "2.00":
-                continue
+        signals = {
+            file.stem: file
+            for file in Path(TestMDF.tempdir_demo.name).iterdir()
+            if file.suffix == '.npy'
+        }
 
-            print(input_file)
+        for file in mdf_files:
+            print(file)
 
-            channels_nr = np.random.randint(1, len(CHANNELS_DEMO) + 1)
+            for inp in (file, BytesIO(file.read_bytes())):
 
-            channel_list = random.sample(list(CHANNELS_DEMO), channels_nr)
+                with MDF(inp, use_display_names=True) as input_file:
 
-            selected_signals = MDF(input_file).select(channel_list)
+                    names = [
+                        ch.name
+                        for gp in input_file.groups
+                        for ch in gp.channels[1:]
+                    ]
 
-            self.assertTrue(len(selected_signals) == len(channel_list))
+                    input_file.configure(read_fragment_size=200)
 
-            self.assertTrue(
-                all(
-                    ch.name == name
-                    for ch, name in zip(selected_signals, channel_list)
-                )
-            )
+                    channels_nr = np.random.randint(1, len(names) + 1)
+                    channel_list = random.sample(names, channels_nr)
 
-            equal = True
+                    selected_signals = input_file.select(channel_list)
 
-            with MDF(input_file) as mdf:
+                    target_names = set(s.name for s in selected_signals)
 
-                for selected in selected_signals:
-                    original = mdf.get(selected.name)
-                    if not np.array_equal(original.samples, selected.samples):
-                        equal = False
-                    if not np.array_equal(original.timestamps, selected.timestamps):
-                        equal = False
+                    self.assertFalse(set(target_names) - set(channel_list))
 
-            self.assertTrue(equal)
+                    for name, sig in zip(channel_list, selected_signals):
+                        target = np.load(signals[name])
+                        self.assertTrue(np.array_equal(target, sig.samples))
 
     def test_scramble(self):
         print("MDF scramble tests")
 
         for input_file in Path(TestMDF.tempdir_demo.name).iterdir():
-            scrambled = MDF.scramble(input_file)
-            self.assertTrue(scrambled)
-            Path(scrambled).unlink()
+            if input_file.suffix.lower() in ('.mdf', '.mf4'):
+                scrambled = MDF.scramble(input_file)
+                self.assertTrue(scrambled)
+                Path(scrambled).unlink()
 
     def test_iter_groups(self):
         dfs = [
-            DataFrame({f'df_{i}_column_0': np.ones(5) * i, f'df_{i}_column_1': np.arange(5) * i})
+            DataFrame(
+                {
+                    f"df_{i}_column_0": np.ones(5) * i,
+                    f"df_{i}_column_1": np.arange(5) * i,
+                }
+            )
             for i in range(5)
         ]
 
@@ -914,7 +918,7 @@ class TestMDF(unittest.TestCase):
             Signal(
                 samples=np.ones(1000) * i,
                 timestamps=np.arange(1000),
-                name=f'Signal_{i}',
+                name=f"Signal_{i}",
             )
             for i in range(20)
         ]
@@ -929,9 +933,9 @@ class TestMDF(unittest.TestCase):
         raster = 1.33
         sigs = [
             Signal(
-                samples=np.arange(1000, dtype='f8'),
+                samples=np.arange(1000, dtype="f8"),
                 timestamps=np.concatenate([np.arange(500), np.arange(1000, 1500)]),
-                name=f'Signal_{i}',
+                name=f"Signal_{i}",
             )
             for i in range(20)
         ]
@@ -941,11 +945,12 @@ class TestMDF(unittest.TestCase):
         mdf = mdf.resample(raster=raster)
 
         target_timestamps = np.arange(0, 1500, 1.33)
-        target_samples = np.concatenate([
-             np.arange(0, 500, 1.33),
-             np.linspace(499.00215568862274, 499.9976646706587, 376),
-             np.arange(500.1600000000001, 1000, 1.33)
-             ]
+        target_samples = np.concatenate(
+            [
+                np.arange(0, 500, 1.33),
+                np.linspace(499.00215568862274, 499.9976646706587, 376),
+                np.arange(500.1600000000001, 1000, 1.33),
+            ]
         )
 
         for i, sig in enumerate(mdf.iter_channels(skip_master=True)):
@@ -954,7 +959,12 @@ class TestMDF(unittest.TestCase):
 
     def test_to_dataframe(self):
         dfs = [
-            DataFrame({f'df_{i}_column_0': np.ones(5) * i, f'df_{i}_column_1': np.arange(5) * i})
+            DataFrame(
+                {
+                    f"df_{i}_column_0": np.ones(5) * i,
+                    f"df_{i}_column_1": np.arange(5) * i,
+                }
+            )
             for i in range(5)
         ]
 
@@ -964,8 +974,8 @@ class TestMDF(unittest.TestCase):
 
         target = {}
         for i in range(5):
-            target[f'df_{i}_column_0'] = np.ones(5) * i
-            target[f'df_{i}_column_1'] = np.arange(5) * i
+            target[f"df_{i}_column_0"] = np.ones(5) * i
+            target[f"df_{i}_column_1"] = np.arange(5) * i
 
         target = DataFrame(target)
 
